Class: Mensa::Base

Inherits:
Object
  • Object
show all
Includes:
ConfigReaders, Scope, Pagy::Method
Defined in:
app/tables/mensa/base.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Methods included from Scope

#filtered_scope, #ordered_scope, #paged_scope, #pagy_details, #selected_scope

Constructor Details

#initialize(config = {}) ⇒ Base

Returns a new instance of Base.



24
25
26
27
28
29
30
31
32
33
34
# File 'app/tables/mensa/base.rb', line 24

def initialize(config = {})
  @params = config.to_h.deep_symbolize_keys
  @config = self.class.definition.merge(@params || {})

  ensure_internal_columns_for_joined_associations

  params[:hidden_columns]&.each do |column_name|
    c = columns.find { |c| c.name == column_name.to_sym }
    c.config[:visible] = false
  end
end

Instance Attribute Details

#componentObject

Returns the value of attribute component.



10
11
12
# File 'app/tables/mensa/base.rb', line 10

def component
  @component
end

#nameObject

Returns the value of attribute name.



10
11
12
# File 'app/tables/mensa/base.rb', line 10

def name
  @name
end

#original_view_contextObject



158
159
160
# File 'app/tables/mensa/base.rb', line 158

def original_view_context
  @original_view_context || component.original_view_context
end

#paramsObject (readonly)

Returns the value of attribute params.



11
12
13
# File 'app/tables/mensa/base.rb', line 11

def params
  @params
end

#requestObject

Returns the value of attribute request.



10
11
12
# File 'app/tables/mensa/base.rb', line 10

def request
  @request
end

#table_viewObject

Returns the value of attribute table_view.



10
11
12
# File 'app/tables/mensa/base.rb', line 10

def table_view
  @table_view
end

Instance Method Details

#actionsObject



103
104
105
106
107
# File 'app/tables/mensa/base.rb', line 103

def actions
  return @actions if @actions

  @actions ||= config[:actions].keys.map { |action_name| Mensa::Action.new(action_name, config: config.dig(:actions, action_name), table: self) }
end

#actions?Boolean

Returns:

  • (Boolean)


99
100
101
# File 'app/tables/mensa/base.rb', line 99

def actions?
  config[:actions].present?
end

#active_filtersObject

Returns the active filters, skipping any whose column no longer exists.



91
92
93
94
95
96
97
# File 'app/tables/mensa/base.rb', line 91

def active_filters
  (config[:filters] || {}).filter_map do |column_name, filter_config|
    col = column(column_name)
    next unless col
    Mensa::Filter.new(column: col, config: filter_config, table: self)
  end
end

#all_viewsObject



138
139
140
141
142
# File 'app/tables/mensa/base.rb', line 138

def all_views
  views = system_views
  views += TableView.where(table_name: name).where(user: [nil, current_user])
  views
end

#batch_actionsObject



113
114
115
116
117
# File 'app/tables/mensa/base.rb', line 113

def batch_actions
  return @batch_actions if @batch_actions

  @batch_actions ||= config[:batches].keys.map { |batch_name| Mensa::BatchAction.new(batch_name, config: config.dig(:batches, batch_name), table: self) }
end

#batch_actions?Boolean

Returns:

  • (Boolean)


109
110
111
# File 'app/tables/mensa/base.rb', line 109

def batch_actions?
  config[:batches].present?
end

#column(name) ⇒ Object

Returns a column by name

Parameters:

  • name (String)


56
57
58
# File 'app/tables/mensa/base.rb', line 56

def column(name)
  columns.find { |c| c.name == name.to_sym }
end

#column_orderObject



36
37
38
39
40
41
42
43
44
45
46
47
# File 'app/tables/mensa/base.rb', line 36

def column_order
  order = config[:column_order].presence || config[:columns]&.keys
  order = order&.map(&:to_sym)
  return order if order.nil?

  # Internal columns are never shown in the column customizer UI, so they
  # are absent from any URL-supplied column_order. Always append them so
  # that columns and selected_scope include their attributes.
  all_keys = (config[:columns]&.keys || []).map(&:to_sym)
  internal_keys = all_keys.select { |key| config.dig(:columns, key, :internal) }
  (order | internal_keys)
end

#columnsObject

Returns all columns



50
51
52
# File 'app/tables/mensa/base.rb', line 50

def columns
  @columns ||= column_order.map { |column_name| Mensa::Column.new(column_name, config: config.dig(:columns, column_name), table: self) }
end

#current_userObject

The user that owns custom views. Returns nil when the host application has no current user, in which case views cannot be saved.



146
147
148
149
150
# File 'app/tables/mensa/base.rb', line 146

def current_user
  return Current.user if defined?(Current) && Current.respond_to?(:user)

  nil
end

#display_columnsObject

Returns the columns to be displayed, ordered by column_order.



61
62
63
64
65
66
67
68
69
# File 'app/tables/mensa/base.rb', line 61

def display_columns
  @display_columns ||= begin
    order = column_order || []
    columns
      .select(&:visible?)
      .reject(&:internal?)
      .sort_by { |col| order.index(col.name) || Float::INFINITY }
  end
end

#export_rowsObject



76
77
78
# File 'app/tables/mensa/base.rb', line 76

def export_rows
  ordered_scope.map { |row| Mensa::Row.new(self, row) }
end

#filters?Boolean

Returns true if the table has filters

Returns:

  • (Boolean)


86
87
88
# File 'app/tables/mensa/base.rb', line 86

def filters?
  columns.any?(&:filter?)
end


132
133
134
135
136
# File 'app/tables/mensa/base.rb', line 132

def menu
  Satis::Menus::Builder.build([:table, :view_menu]) do |m|
    m.item :export, icon: "fal fa-file-export", link: nil
  end
end

#path(order: {}, turbo_frame_id: nil, table_view_id: , column_order: , hidden_columns: ) ⇒ Object

Returns the current path with configuration



120
121
122
123
124
125
126
127
128
129
130
# File 'app/tables/mensa/base.rb', line 120

def path(order: {}, turbo_frame_id: nil, table_view_id: params[:table_view_id], column_order: params[:column_order], hidden_columns: params[:hidden_columns])
  # FIXME: if someone doesn't use as: :mensa in the routes, it breaks
  original_view_context.mensa.table_path(
    name,
    order: order_hash(order),
    turbo_frame_id: turbo_frame_id,
    table_view_id: table_view_id,
    column_order: column_order,
    hidden_columns: hidden_columns
  )
end

#rowsObject

Returns the rows to be displayed



72
73
74
# File 'app/tables/mensa/base.rb', line 72

def rows
  paged_scope.map { |row| Mensa::Row.new(self, row) }
end

#system_viewsObject



80
81
82
83
# File 'app/tables/mensa/base.rb', line 80

def system_views
  views = config[:views]&.key?(:default) ? [] : [Mensa::SystemView.new(:default, config: {name: I18n.t("mensa.views.default")}, table: self)]
  views + (config[:views] || {}).keys.map { |view_name| Mensa::SystemView.new(view_name, config: config.dig(:views, view_name), table: self) }
end

#table_idObject



152
153
154
155
156
# File 'app/tables/mensa/base.rb', line 152

def table_id
  return @table_id if @table_id

  @table_id = params[:turbo_frame_id] || "#{name.to_s.gsub("/", "__")}-#{SecureRandom.base36}"
end