Class: Mensa::Filter
- Inherits:
-
Object
- Object
- Mensa::Filter
- Includes:
- ConfigReaders
- Defined in:
- app/tables/mensa/filter.rb
Instance Attribute Summary collapse
-
#column ⇒ Object
readonly
Returns the value of attribute column.
-
#table ⇒ Object
readonly
Returns the value of attribute table.
Class Method Summary collapse
Instance Method Summary collapse
-
#as ⇒ Object
This defines how the filter should be displayed in the value popover :select => as a select input :checkbox => as a checkbox input :string => as a text input.
- #collection ⇒ Object
- #filter_scope(record_scope) ⇒ Object
- #formatted_value ⇒ Object
-
#initialize(column:, config:, table:) ⇒ Filter
constructor
A new instance of Filter.
- #input_type ⇒ Object
- #multiple? ⇒ Boolean
- #operator_label ⇒ Object
- #operator_with_value? ⇒ Boolean
- #operators ⇒ Object
- #query_and_hash_for_operator ⇒ Object
- #to_s ⇒ Object
Constructor Details
#initialize(column:, config:, table:) ⇒ Filter
Returns a new instance of Filter.
34 35 36 37 38 |
# File 'app/tables/mensa/filter.rb', line 34 def initialize(column:, config:, table:) @column = column @config = self.class.definition.merge(config || {}) @table = table end |
Instance Attribute Details
#column ⇒ Object (readonly)
Returns the value of attribute column.
9 10 11 |
# File 'app/tables/mensa/filter.rb', line 9 def column @column end |
#table ⇒ Object (readonly)
Returns the value of attribute table.
9 10 11 |
# File 'app/tables/mensa/filter.rb', line 9 def table @table end |
Class Method Details
.OPERATORS ⇒ Object
17 18 19 20 21 22 23 24 25 26 27 28 29 30 31 |
# File 'app/tables/mensa/filter.rb', line 17 def OPERATORS [ [:is, I18n.t("mensa.operators.is"), true], [:isnt, I18n.t("mensa.operators.isnt"), true], [:matches, I18n.t("mensa.operators.matches"), true], [:does_not_match, I18n.t("mensa.operators.does_not_match"), true], [:gt, I18n.t("mensa.operators.gt"), true], [:gteq, I18n.t("mensa.operators.gteq"), true], [:lt, I18n.t("mensa.operators.lt"), true], [:lteq, I18n.t("mensa.operators.lteq"), true], [:is_current, I18n.t("mensa.operators.is_current"), false], [:is_empty, I18n.t("mensa.operators.is_empty"), false], [:isnt_empty, I18n.t("mensa.operators.isnt_empty"), false] ].freeze end |
Instance Method Details
#as ⇒ Object
This defines how the filter should be displayed in the value popover :select => as a select input :checkbox => as a checkbox input :string => as a text input
58 59 60 |
# File 'app/tables/mensa/filter.rb', line 58 def as config[:as] end |
#collection ⇒ Object
44 45 46 47 48 49 50 51 52 |
# File 'app/tables/mensa/filter.rb', line 44 def collection return unless config&.key?(:collection) if config[:collection].is_a? Proc table.original_view_context.instance_exec(&config[:collection]) else config[:collection] end end |
#filter_scope(record_scope) ⇒ Object
78 79 80 81 82 83 84 85 86 |
# File 'app/tables/mensa/filter.rb', line 78 def filter_scope(record_scope) if scope record_scope.instance_exec(normalize(value), &scope) else query, hash = query_and_hash_for_operator record_scope = record_scope.where(query, hash) if query.present? record_scope end end |
#formatted_value ⇒ Object
68 69 70 71 72 73 74 75 76 |
# File 'app/tables/mensa/filter.rb', line 68 def formatted_value = if value.is_a?(Array) value.map { |entry| label_for_value(entry, ) }.join(", ") else label_for_value(value, ) end end |
#input_type ⇒ Object
145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'app/tables/mensa/filter.rb', line 145 def input_type case column.type when :integer "number" when :date "date" when :datetime "datetime-local" else "text" end end |
#multiple? ⇒ Boolean
40 41 42 |
# File 'app/tables/mensa/filter.rb', line 40 def multiple? !!multiple end |
#operator_label ⇒ Object
137 138 139 |
# File 'app/tables/mensa/filter.rb', line 137 def operator_label Mensa::Filter.OPERATORS.find { |op| op[0] == operator }[1] end |
#operator_with_value? ⇒ Boolean
141 142 143 |
# File 'app/tables/mensa/filter.rb', line 141 def operator_with_value? Mensa::Filter.OPERATORS.find { |op| op[0] == operator }[2] end |
#operators ⇒ Object
88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'app/tables/mensa/filter.rb', line 88 def operators operators = Mensa::Filter.OPERATORS.dup if config[:operators].present? operators = operators.select { |op| config[:operators].include?(op[0]) } else operators.delete_if { |op| op[0] == :is_current } unless Current.method_defined?(column.name, false) operators.delete_if { |op| [:matches, :does_not_match].include?(op[0]) } if collection.present? operators.delete_if { |op| [:matches, :does_not_match].include?(op[0]) } if column.type == :integer || column.type == :date || column.type == :datetime operators.delete_if { |op| [:is, :isnt].include?(op[0]) } if column.type == :date || column.type == :datetime operators.delete_if { |op| [:gt, :lt, :gteq, :lteq].include?(op[0]) } if column.type == :string || column.type.blank? end operators end |
#query_and_hash_for_operator ⇒ Object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'app/tables/mensa/filter.rb', line 102 def query_and_hash_for_operator hash = { column: column.attribute_for_condition, value: normalize(value) } query = case operator when :is_empty column.type == :string ? ":column IS NULL OR :column = ''" : ":column IS NULL" when :isnt_empty column.type == :string ? ":column IS NOT NULL AND :column != ''" : ":column IS NOT NULL" when :is_current ":column = :value" when :matches ":column LIKE :value" when :does_not_match ":column NOT LIKE :value" when :is hash[:value] = value if hash[:value].is_a?(Array) ":column = :value" when :isnt hash[:value] = value if hash[:value].is_a?(Array) ":column != :value" when :gt ":column > :value" when :lt ":column < :value" when :gteq ":column >= :value" when :lteq ":column <= :value" else # Ignore unknown operators nil end [query, hash] end |
#to_s ⇒ Object
62 63 64 65 66 |
# File 'app/tables/mensa/filter.rb', line 62 def to_s parts = [column.human_name, operator_label] parts << formatted_value if formatted_value.present? && operator_with_value? parts.join(" ") end |